@@ -1,7 +1,7 @@
 #---------------------------------------------------------------------------
 # Simulate partial and full replicate design and scaled ABE power
 # using 'widened' limits (EMA)
-# But the estimation method via intra-subject contrasts (FDA)
+# But the estimation method via intra-subject contrasts (FDA, HC)
 #
 # Author: dlabes
 #---------------------------------------------------------------------------
@@ -15,7 +15,7 @@
 
 power.scABEL2 <- function(alpha=0.05, theta1, theta2, theta0, CV, n,   
                           design=c("2x3x3", "2x2x4", "2x2x3"), regulator,
-                          nsims=1E5, details=FALSE, setseed=TRUE)
+                          nsims, details=FALSE, setseed=TRUE)
 {
   # function is no longer visible via NAMESPACE
   # .Deprecated(new="power.scABEL", msg=paste0("'power.scABEL2' is deprecated.",
@@ -36,6 +36,15 @@ power.scABEL2 <- function(alpha=0.05, theta1, theta2, theta0, CV, n,
   
   CVwT <- CV[1]
   if (length(CV)==2) CVwR <- CV[2] else CVwR <- CVwT
+
+  if (missing(nsims)) { # not given
+    if (theta0 == scABEL(CVwR)[["lower"]] | theta0 == scABEL(CVwR)[["upper"]]) {
+      nsims <- 1e6 # simulating TIE
+    } else {
+      nsims <- 1e5 # simulating power
+    }
+  }
+  
   s2wT <- log(1.0 + CVwT^2)
   s2wR <- log(1.0 + CVwR^2)
 
@@ -127,7 +136,7 @@ power.scABEL2 <- function(alpha=0.05, theta1, theta2, theta0, CV, n,
             formatC(ptm["elapsed"], digits=2), "\n")
     #print(ptm)
     # return also the components
-    names(p) <- c("p(BE)", "p(BE-wABEL)", "p(BE-pe)", "p(BE-ABE)")
+    names(p) <- c("p(BE)", "p(BE-ABEL)", "p(BE-pe)", "p(BE-ABE)")
     if (!pe_constr) p <- p[-3] # without pe constraint
     p
   } else {
@@ -135,69 +144,3 @@ power.scABEL2 <- function(alpha=0.05, theta1, theta2, theta0, CV, n,
     as.numeric(p["BE"])
   }
 }
-
-# working horse
-.pwr.ABEL.ISC <- function(mlog, sdm, C3, Emse, df, s2wR, dfRR, nsims, 
-                          CVswitch, r_const, CVcap, pe_constr, ln_lBEL, ln_uBEL, 
-                          alpha)
-{
-  tval     <- qt(1-alpha, df)
-  s2switch <- log(CVswitch^2+1)
-  s2cap    <- log(CVcap^2+1)
-  
-  counts <- rep.int(0, times=4)
-  names(counts) <- c("BE", "BEwl", "BEpe", "BEabe")
-  # to avoid memory problems for high number of sims we are working in chunks
-  chunks <- 1
-  nsi    <- nsims
-  if (nsims>1E7) {
-    chunks <- ceiling(nsims/1E7)
-    nsi    <- 1E7
-  } 
-  for (iter in 1:chunks) {
-    # if chunks*1E7 > nsims correct nsi to given nsims at the end
-    if(iter==chunks) nsi <- nsims-(chunks-1)*nsi
-    # simulate sample mean via its normal distribution
-    means  <- rnorm(nsi, mean=mlog, sd=sdm)
-    # simulate sample sd2s via chi-square distri
-    sd2s   <- Emse*C3*rchisq(nsi, df)/df
-    # simulate sample value s2wRs via chi-square distri
-    s2wRs  <- s2wR*rchisq(nsi, dfRR)/dfRR
-    
-    SEs <- sqrt(sd2s)
-    # conventional (1-2*alpha) CI's for T-R
-    hw  <- tval*SEs
-    lCL <- means - hw 
-    uCL <- means + hw
-    # conventional ABE
-    BEABE <- (lCL>=ln_lBEL) & (uCL<=ln_uBEL)
-    
-    #--- widened limits in log-domain
-    uABEL <- +sqrt(s2wRs)*r_const
-    # cap on 'widened' limits
-    uABEL[s2wRs>s2cap] <- sqrt(s2cap)*r_const
-    # BE using widened acceptance limits
-    BE <- (lCL>=-uABEL) & (uCL<=uABEL)
-    
-    # pe constraint
-    BEpe  <- ( means>=ln_lBEL & means<=ln_uBEL )
-    
-    # save memory
-    rm(SEs, hw, uABEL)
-    
-    # if CV < CV switch use ABE, else scABEL
-    BE    <- ifelse(s2wRs>s2switch, BE, BEABE)
-
-    counts["BEabe"] <- counts["BEabe"] + sum(BEABE)
-    counts["BEpe"]  <- counts["BEpe"]  + sum(BEpe)
-    counts["BEwl"]  <- counts["BEwl"]  + sum(BE)
-    if (pe_constr) {
-      counts["BE"] <- counts["BE"] + sum(BE & BEpe) # with pe constraint
-    } else {
-      counts["BE"] <- counts["BE"] + sum(BE) # without pe constraint
-    }
-    
-  } # end over chunks
-  # return the pBEs
-  counts/nsims
-}
\ No newline at end of file
